pub struct Cfb<C> { /* private fields */ }Expand description
Cipher Feedback (CFB) mode with a segment size equal to the full block.
Implementations
Sourceimpl<C: BlockCipher> Cfb<C>
impl<C: BlockCipher> Cfb<C>
Sourcepub fn encrypt_nopad(&self, iv: &[u8], data: &mut [u8])
pub fn encrypt_nopad(&self, iv: &[u8], data: &mut [u8])
Panics
Panics if iv.len() does not match the block size, or if data.len()
is not an exact multiple of the block size.
Sourcepub fn decrypt_nopad(&self, iv: &[u8], data: &mut [u8])
pub fn decrypt_nopad(&self, iv: &[u8], data: &mut [u8])
Panics
Panics if iv.len() does not match the block size, or if data.len()
is not an exact multiple of the block size.