Xts

Struct Xts 

pub struct Xts<C> { /* private fields */ }
XEX-based Tweaked CodeBook mode with ciphertext Stealing (XTS).

This implementation supports 128-bit block ciphers, which is the case covered by SP 800-38E / XTS-AES.

Implementations

Source

impl<C> Xts<C>

pub fn new(data_cipher: C, tweak_cipher: C) -> Self

Wrap a pair of block ciphers in SP 800-38E XTS mode.

data_cipher encrypts the sector payload blocks. tweak_cipher derives the per-sector tweak stream from the caller-supplied tweak.

pub fn data_cipher(&self) -> &C

Borrow the data-encryption cipher.

pub fn tweak_cipher(&self) -> &C

Borrow the tweak-derivation cipher.

Source

impl<C: BlockCipher> Xts<C>

pub fn encrypt_sector(&self, tweak_value: &[u8; 16], data: &mut [u8])

Panics

Panics if the wrapped cipher does not have a 128-bit block size, or if data is shorter than one complete block.

pub fn decrypt_sector(&self, tweak_value: &[u8; 16], data: &mut [u8])

Panics

Panics if the wrapped cipher does not have a 128-bit block size, or if data is shorter than one complete block.