DhPublicKey

Struct DhPublicKey 

pub struct DhPublicKey { /* private fields */ }
Public key for DH.

Implementations

Source

impl DhPublicKey

pub fn modulus(&self) -> &BigUint

pub fn subgroup_order(&self) -> &BigUint

pub fn generator(&self) -> &BigUint

pub fn public_component(&self) -> &BigUint

The public component y = g^x mod p.

pub fn params(&self) -> DhParams

pub fn to_key_blob(&self) -> Vec<u8>

Encode in binary format: [p, q, g, y].

pub fn from_key_blob(blob: &[u8]) -> Option<Self>

Decode from binary format.

pub fn to_pem(&self) -> String

pub fn from_pem(pem: &str) -> Option<Self>

Returns None if the PEM label does not match or the payload is malformed.

pub fn to_xml(&self) -> String

pub fn from_xml(xml: &str) -> Option<Self>

Returns None if the XML is malformed or y is out of range.