pub struct AffinePoint {
pub x: BigUint,
pub y: BigUint,
pub infinity: bool,
}Expand description
An affine curve point, or the point at infinity.
The coordinates are ordinary residues in [0, p). The point at infinity
is the group identity: P + ∞ = P and n·G = ∞.
Fields
x: BigUintx-coordinate. Meaningful only when !infinity.
y: BigUinty-coordinate. Meaningful only when !infinity.
infinity: booltrue when this represents the point at infinity (the group identity).
Implementations
Sourceimpl AffinePoint
impl AffinePoint
Sourcepub fn new(x: BigUint, y: BigUint) -> Self
pub fn new(x: BigUint, y: BigUint) -> Self
A finite affine point (x, y).
The caller is responsible for ensuring that (x, y) lies on the
intended curve; use CurveParams::is_on_curve to validate.
Sourcepub fn is_infinity(&self) -> bool
pub fn is_infinity(&self) -> bool
Return true if this is the point at infinity.