pub struct SchmidtSamoaPrivateKey { /* private fields */ }Expand description
Private key for the Schmidt-Samoa primitive.
Implementations
Sourceimpl SchmidtSamoaPrivateKey
impl SchmidtSamoaPrivateKey
Sourcepub fn decrypt_raw(&self, ciphertext: &BigUint) -> BigUint
pub fn decrypt_raw(&self, ciphertext: &BigUint) -> BigUint
Apply the raw private map c^d mod gamma.
This recovers the original message only for plaintexts represented in
the range [0, gamma).
Sourcepub fn decrypt(&self, ciphertext: &BigUint) -> Vec<u8> ⓘ
pub fn decrypt(&self, ciphertext: &BigUint) -> Vec<u8> ⓘ
Decrypt a ciphertext back into the big-endian byte string that was interpreted as the plaintext integer.
Sourcepub fn decrypt_bytes(&self, ciphertext: &[u8]) -> Option<Vec<u8>>
pub fn decrypt_bytes(&self, ciphertext: &[u8]) -> Option<Vec<u8>>
Decrypt a byte-encoded ciphertext produced by SchmidtSamoaPublicKey::encrypt_bytes.
Sourcepub fn to_key_blob(&self) -> Vec<u8> ⓘ
pub fn to_key_blob(&self) -> Vec<u8> ⓘ
Encode the private key in the crate-defined binary format.
Sourcepub fn from_key_blob(blob: &[u8]) -> Option<Self>
pub fn from_key_blob(blob: &[u8]) -> Option<Self>
Decode the private key from the crate-defined binary format.